#

##

##

##

##

##

##

###

###

    	petitions
    		# moves
    		# glamour

    	tags
    		# proposals
    		# asks
    		# choices
    		# RPC
    		# API
    		# websockets
    		# cli

    	summary

    	chapter 1, founder sequences
    		# genesis
    		# origins
    		# earlies

    	chapter 2, voters

    	chapter 3, mottoes

    	chapter 3, escrow

    		send escrow

    		receive escrow